convert_gct <- function(df, meta_df, output_filepath){
    require(mapGCT)
    # Identify the columns to keep based on column names. probe_id, entrez and columns with suffix _gpl are to be dropped from data matrix 
    # and to be kept in row meta df
    columns_to_keep <- c("probe_id", "entrez", colnames(df)[grep("_gpl", colnames(df))])

    # add probes and GPL table metadata to row metadata
    row_meta_df <- df[, columns_to_keep, drop = FALSE]
    rownames(row_meta_df) <- rownames(df[, columns_to_keep, drop = FALSE])
    
    # exclude probe and other GPL table columns in matrix df
    df <- df[, !colnames(df) %in% columns_to_keep]
    # Remove the "_gpl" suffix from column names in row_meta_df
    cleaned_names <- sub("_gpl$", "", colnames(row_meta_df))
    # Assign the cleaned column names back to the DataFrame
    colnames(row_meta_df) <- cleaned_names
    #drop ID column because it is the same as probe_id
    row_meta_df <- row_meta_df[, !colnames(row_meta_df) %in% "ID"]

    # convert to numeric
    df[] <- sapply(df, as.numeric)
    print("df and meta col names")
    print(names(df))
    print(names(meta_df))
    # check set equality of colnames of matrix and row names of metadata
    if(!setequal(colnames(df), rownames(meta_df))){
        missing_samples <- c(setdiff(colnames(df), rownames(meta_df)),
                            setdiff(rownames(meta_df), colnames(df)))
        if (length(missing_samples[!(missing_samples %in% c('probe_id','entrez'))])>0)
            stop(paste0("samples ", paste(missing_samples, collapse = ", "),
                        "are not present in both matrix and metadata"))
    }

    
    # reorder metadata by sample names order of matrix
    meta_df <- meta_df[colnames(df), ]

    # make the gct and save to output path
    GCT_object <- to_GCT(mat=as.matrix(df), cdesc=meta_df, rdesc=row_meta_df)
    write_gct(GCT_object, output_filepath)
    return(output_filepath)
}
